@@ -73,6 +73,11 @@ protected:
 	virtual void update(void);
 
 public:
+	/**
+	 * index elements.
+	 */
+	typedef enum {year = 10, month, day, dow} index_t;
+
 	/**
 	 * Size of date string field.
 	 */
@@ -196,6 +201,20 @@ public:
 	inline operator long() const
 		{return get();};
 
+	/**
+	 * Access numeric components.
+	 * @param component to access.
+	 * @return value of component.
+	 */
+	int operator[](index_t component) const;
+
+	/**
+	 * Access julian value.
+	 * @return julian number of object.
+	 */
+	inline long operator*() const
+		{return get();};
+
 	/**
 	 * Expression operator to return an ISO date string for the current
 	 * julian date.
@@ -337,6 +356,11 @@ protected:
 	virtual void update(void);
 
 public:
+	/**
+	 * Component access index.
+	 */
+	typedef enum {hour = 20, minute, second} index_t;
+
 	/**
 	 * Size of time string field.
 	 */
@@ -475,6 +499,20 @@ public:
 	 */
 	inline operator long()
 		{return get();};
+
+	/**
+	 * Get object time in seconds.
+	 * @return time in seconds.
+	 */
+	inline long operator*() const
+		{return get();};
+
+	/**
+	 * Get component of time object.
+	 * @param component index.
+	 * @return value of component.
+	 */
+	int operator[](index_t) const;
 	
 	/**
 	 * Convert to standard 24 hour time string.
@@ -574,6 +612,13 @@ protected:
 	void update(void);
 
 public:
+	/**
+	 * Index to components we can access.
+	 */
+	typedef enum {year = Date::year, month = Date::month, day = Date::day, 
+		dow = Date::dow, 
+		hour = Time::hour, minute = Time::minute, second = Time::second} index_t;
+
 	/**
 	 * Constant for number of seconds in a day.
 	 */
@@ -768,6 +813,13 @@ public:
 	 */
 	bool operator!() const;
 
+	/**
+	 * Access time components.
+	 * @param component to access.
+	 * @return number or -1 if invalid.
+	 */
+	int operator[](index_t component) const;
+
 	/**
 	 * Test is date and time is valid for is() operator.
 	 * @return true if object is valid.
@@ -853,7 +905,6 @@ protected:
 public:
 	/**
 	 * Construct a date and time from C libraray time_t type.		
-	 * @param string mode to use.
 	 * @param time type to make date and time from.
 	 */
   	DateTimeString(time_t time);
