@@ -64,13 +64,6 @@ struct addrinfo;
 #define	DEFAULT_FAMILY	AF_INET
 #endif
 
-/**
- * An object that can hold a ipv4 or ipv6 socket address.  This would be
- * used for tcpip socket connections.  We do not use sockaddr_storage
- * because it is not present in pre ipv6 stacks, and because the storage
- * size also includes the size of the path of a unix domain socket on
- * posix systems.
- */
 struct sockaddr_internet;
 
 /**
@@ -88,6 +81,13 @@ typedef struct hostaddr_internet
 }	inethostaddr_t;
 
 #if defined(AF_INET6) || defined(__CYGWIN__)
+/**
+ * An object that can hold a ipv4 or ipv6 socket address.  This would be
+ * used for tcpip socket connections.  We do not use sockaddr_storage
+ * because it is not present in pre ipv6 stacks, and because the storage
+ * size also includes the size of the path of a unix domain socket on
+ * posix systems.
+ */
 typedef struct sockaddr_internet
 {
 	union {
@@ -363,67 +363,67 @@ public:
 		 * Get the first socket address in our address list.
 		 * @return first socket address or NULL if none.
 		 */
-		struct sockaddr *getAddr(void);
+		struct sockaddr *getAddr(void) const;
 
 		/**
 		 * Get the first socket address of specified family from our list.
 		 * @param family to seek.
 		 * @return first socket address of family or NULL if none.
 		 */
-		struct sockaddr *get(int family);
+		struct sockaddr *get(int family) const;
 
 		/**
 		 * Get the family of a socket address by first entry.
 		 * @return family of first socket address or 0 if none.
 		 */
-		int getfamily(void);
+		int getfamily(void) const;
 
 		/**
 		 * Find a specific socket address in our address list.
 		 * @return matching address from list or NULL if not found.
 		 */
-		struct sockaddr *find(struct sockaddr *addr);
+		struct sockaddr *find(struct sockaddr *addr) const;
 
 		/**
 		 * Get the full socket address list from the object.
 		 * @return addrinfo list we resolved or NULL if none.
 		 */
-		inline struct addrinfo *getList(void)
+		inline struct addrinfo *getList(void) const
 			{return list;};
 
 		/**
 		 * Get the full socket address list by casted reference.
 		 * @return addrinfo list we resolved or NULL if none.
 		 */
-		inline operator struct addrinfo *()
+		inline operator struct addrinfo *() const
 			{return list;};
 
 		/**
 		 * Return the full socket address list by pointer reference.
 		 * @return addrinfo list we resolved or NULL if none.
 		 */
-		inline struct addrinfo *operator*()
+		inline struct addrinfo *operator*() const
 			{return list;};
 
 		/**
 		 * Test if the address list is valid.
 		 * @return true if we have an address list.
 		 */
-		inline operator bool()
+		inline operator bool() const
 			{return list != NULL;};
 
 		/**
 		 * Test if we have no address list.
 		 * @return true if we have no address list.
 		 */
-		inline bool operator!()
+		inline bool operator!() const
 			{return list == NULL;};
 
 		/**
 		 * Get the first socket address by casted reference.
 		 * @return first socket address we resolved or NULL if none.
 		 */
-		inline operator struct sockaddr *()
+		inline operator struct sockaddr *() const
 			{return getAddr();};
 
 		/**
@@ -741,7 +741,7 @@ public:
 	/**
 	 * Set segment size and get MTU.
 	 * @param socket to modify.
-	 * @param segment size or zero to not set.
+	 * @param size of segment or zero to not set.
 	 * @return mtu size of socket.
 	 */
 	static unsigned segsize(socket_t socket, unsigned size = 0);
@@ -763,7 +763,7 @@ public:
 
 	/**
 	 * Set segment size and get mtu of a socket.
-	 * @param segment size to set or 0 to leave unchanged.
+	 * @param size of segment or 0 to leave unchanged.
 	 * @return mtu size.
 	 */
 	inline unsigned segsize(unsigned size)
@@ -1564,6 +1564,36 @@ inline struct addrinfo *addrinfo(socket::address& address)
 inline struct sockaddr *addr(socket::address& address)
 	{return address.getAddr();}
 
+/**
+ * Compare two socket addresses to see if equal.  If the port is zero
+ * then this is the same as comparing host address alone.
+ * @param s1 socket address to compare.
+ * @param s2 socket address to compare.
+ * @return true if addresses same.
+ */
+inline bool eq(struct sockaddr *s1, struct sockaddr *s2)
+	{return Socket::equal(s1, s2);}
+
+/**
+ * Compare two stored socket addresses to see if equal.  If the port is zero
+ * then this is the same as comparing host address alone.
+ * @param s1 stored socket address to compare.
+ * @param s2 stored socket address to compare.
+ * @return true if addresses same.
+ */
+inline bool eq(struct sockaddr_storage *s1, struct sockaddr_storage *s2)
+	{return Socket::equal((struct sockaddr *)s1, (struct sockaddr *)s2);}
+
+/**
+ * Compare two host addresses to see if equal.  The port numbers are
+ * ignored.
+ * @param s1 socket address to compare.
+ * @param s2 socket address to compare.
+ * @return true if addresses same.
+ */
+inline bool ieq(struct sockaddr *s1, struct sockaddr *s2)
+	{return Socket::equalhost(s1, s2);}
+
 END_NAMESPACE
 
 #endif
