@@ -1680,6 +1680,11 @@ public:
 	 */
 	queue(mempager *pager = NULL, size_t number = 0);
 
+	/**
+	 * Destroy queue.  If no mempager is used, then frees heap.
+	 */
+	~queue();
+
 	/**
 	 * Remove a specific object pointer for the queue.  This can remove
 	 * a member from any location in the queue, whether beginning, end, or
@@ -1805,6 +1810,11 @@ public:
 	 */
 	stack(mempager *pager = NULL, size_t number = 0);
 
+	/**
+	 * Destroy queue.  If no pager is used, then frees heap.
+	 */
+	~stack();
+
 	/**
 	 * Remove a specific object pointer for the queue.  This can remove
 	 * a member from any location in the queue, whether beginning, end, or
